<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://metabox.io/docs/registering-meta-boxes/
 */
add_filter( 'rwmb_meta_boxes', 'snsnitan_register_meta_boxes' );
/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @param array $meta_boxes List of meta boxes
 *
 * @return array
 */
function snsnitan_register_meta_boxes( $meta_boxes ){
	/**
	 * prefix of meta keys (optional)
	 * Use underscore (_) at the beginning to make keys hidden
	 * Alt.: You also can make prefix empty to disable it
	 */
	// Better has an underscore as last sign
	wp_enqueue_script('sns-imgselect', SNSNITAN_THEME_URI . '/framework/meta-box/sns-metabox.js', array('jquery'), '', true);
	$prefix = 'snsnitan_';
	global $wpdb, $snsnitan_opt;
	$revsliders =array();
	$revsliders[0] = 'Select a slider';
	if (is_plugin_active('revslider/revslider.php')) {
		$query = $wpdb->prepare("
			SELECT * 
			FROM {$wpdb->prefix}revslider_sliders 
			ORDER BY %s"
			, "ASC");
	    $get_sliders = $wpdb->get_results($query);
	    if($get_sliders) {
		    foreach($get_sliders as $slider) {
			   $revsliders[$slider->alias] = $slider->title;
		   }
	    }
	}
	//
	$default_layout = 'm-r';
	if ( isset($snsnitan_opt['blog_layout']) ) $default_layout = $snsnitan_opt['blog_layout'];
	//
	$siderbars = array();
	foreach ($GLOBALS['wp_registered_sidebars'] as $sidebars) {
		$siderbars[ $sidebars['id']] = $sidebars['name'];
	}
	// Layout config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_productcfg',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Product Config', 'snsnitan' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'product' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			 array(
					'name'    => esc_html__( 'Product Sidebar', 'snsnitan' ),
					'id'       => "{$prefix}product_sidebar",
					'type'     => 'select',
					'std'  => '',
					'options'  => array(
						''  => esc_html__( 'Default', 'snsnitan' ),
						'0'  => esc_html__( 'No', 'snsnitan' ),
						'1'  => esc_html__( 'Yes', 'snsnitan' ),
					),
					'desc'		=> esc_html__('Product page with Sidebar. Select "Default" to use in Theme Options.', 'snsnitan'),
				),
			  array(
					'name'    => esc_html__( 'Cloud Zoom', 'snsnitan' ),
					'id'       => "{$prefix}woo_zoomtype",
					'type'     => 'select',
					'std'  => '',
					'options'  => array(
						''  => esc_html__( 'Default', 'snsnitan' ),
						'window'  => esc_html__( 'window', 'snsnitan' ),
						'lens'  => esc_html__( 'lens', 'snsnitan' ),
						'inner'  => esc_html__( 'Inner', 'snsnitan' ),
					),
					'desc'		=> '',
				),
			array(
				'id'    => "{$prefix}product_video",
				'name'  => esc_html__( 'Product Video', 'snsnitan' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				'desc'		  => esc_html__( 'Enter your video url(youtube, video)', 'snsnitan' ),
				// Input size
				'size'  => 50,
			)
		)
	);

	// Layout config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_layout',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Layout Config', 'snsnitan' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			
			array(
				'name'        => esc_html__( 'Config layout for this page', 'snsnitan' ),
				'id'          => "{$prefix}enablelayoutconfig",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '2',
				'desc'		  => esc_html__( 'Sellect Yes if you want config layout for this page', 'snsnitan' ),
			),
			// Layout Type
			array(
				'name'        => esc_html__( 'Layout Type', 'snsnitan' ),
				'id'          => "{$prefix}layouttype",
				'type'        => 'layouttype',
				// Array of 'value' => 'Label' pairs for select box
				'options'     => array(
					'm' => esc_html__( 'Without Sidebar', 'snsnitan' ),
					'l-m' => esc_html__( 'Use Left Sidebar', 'snsnitan' ),
					'm-r' => esc_html__( 'Use Right Sidebar', 'snsnitan' ),
					//'l-m-r' => esc_html__( 'Use Left & Right Sidebar', 'snsnitan' ),
				),
				// Select multiple values, optional. Default is false.
				'multiple'    => false,
				'std'         => $default_layout,
				'placeholder' => esc_html__( '--- Select a layout type ---', 'snsnitan' ),
			),
			// Left Sidebar
			array(
				'name'  => esc_html__( 'Left Sidebar', 'snsnitan' ),
				'id'    => "{$prefix}leftsidebar",
				//'desc'  => esc_html__( 'Text description', 'snsnitan' ),
				'type'  => 'select',
				'options'	=> $siderbars,
				'multiple'	=> false,
				'std'		=> 'left-sidebar',
				'placeholder' => esc_html__( '--- Select a sidebar ---', 'snsnitan' ),
			),
			// Right Sidebar
			array(
				'name'  => esc_html__( 'Right Sidebar', 'snsnitan' ),
				'id'    => "{$prefix}rightsidebar",
				//'desc'  => esc_html__( 'Text description', 'snsnitan' ),
				'type'  => 'select',
				'options'	=> $siderbars,
				'multiple'	=> false,
				'std'		=> 'right-sidebar',
				'placeholder' => esc_html__( '--- Select a sidebar ---', 'snsnitan' ),
			),
			
		)
	);
	
	$menus = get_terms('nav_menu', array( 'hide_empty' => false ));
	$menu_options[''] = esc_html__('Default Menu...', 'snsnitan');
	foreach ( $menus as $menu ){
		$menu_options[$menu->term_id] = $menu->name;
	}
	
	// Page config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_pageconfig',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Page Config', 'snsnitan' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			array(
				'name'    => esc_html__( 'Full Width For Body', 'snsnitan' ),
				'id'      => "{$prefix}fullwidth",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '0',
				
			),
			 array(
			 	'name'    => esc_html__( 'Use Boxed Layout', 'snsnitan' ),
				'id'      => "{$prefix}use_boxedlayout",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'0' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '0',
            ),

		    array(
		    	'name'    => esc_html__( 'Body Background Color', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg-color",
		       'type'    => 'color',
		        'default'	=> '#333333',
		        'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
		    ),
		     array(
		    	'name'    => esc_html__( 'Body Background type img', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg_type_img",
		       'type'    => 'image_advanced',
		        'default'	=> '',
		       
		    ),
		    array(
		    	'name'    => esc_html__( '_', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg-repeat-select",
		        'type'    => 'select',
		        'default'	=> '',
		        'options'  => array(
					'no-repeat'  => esc_html__( 'No Repeat', 'snsnitan' ),
					'repeat'  => esc_html__( 'Repeat All', 'snsnitan' ),
					'repeat-x'  => esc_html__( 'Repeat Horizontally', 'snsnitan' ),
					'repeat-y'  => esc_html__( 'Repeat Vertically', 'snsnitan' ),
					'inherit'  => esc_html__( 'Inherit', 'snsnitan' ),
				),
		    ),
		    array(
		    	'name'    => esc_html__( '_', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg-size-select",
		       'type'    => 'select',
		        'default'	=> '',
		        'options'  => array(
					'cover'  => esc_html__( 'Cover', 'snsnitan' ),
					'contain'  => esc_html__( 'Contain', 'snsnitan' ),
					'inherit'  => esc_html__( 'Inherit', 'snsnitan' ),
				),
		      
		    ),
		    array(
		    	'name'    => esc_html__( '_', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg-position-select",
		       'type'    => 'select',
		        'default'	=> '',
		        'options'  => array(
					'Center Top'  => esc_html__( 'Center Top', 'snsnitan' ),
					'Center Center'  => esc_html__( 'Center Center', 'snsnitan' ),
					'Center Bottom'  => esc_html__( 'Center Bottom', 'snsnitan' ),
					'Left Top'  => esc_html__( 'Left Top', 'snsnitan' ),
					'Left Center'  => esc_html__( 'Left Center', 'snsnitan' ),
					'Left Bottom'  => esc_html__( 'Left Bottom', 'snsnitan' ),
					'Right Top'  => esc_html__( 'Right Top', 'snsnitan' ),
					'Right Center'  => esc_html__( 'Right Center', 'snsnitan' ),
					'Right Bottom'  => esc_html__( 'Right Bottom', 'snsnitan' ),
				),
		    ),
		     array(
		    	'name'    => esc_html__( '_', 'snsnitan' ),
			 	'id'       => "{$prefix}body_bg-attachment-select",
		       'type'    => 'select',
		        'default'	=> '',
		        'options'  => array(
					'scroll'  => esc_html__( 'Scroll', 'snsnitan' ),
					'fixed'  => esc_html__( 'Fixed', 'snsnitan' ),
					'inherit'  => esc_html__( 'Inherit', 'snsnitan' ),
				),
		        'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
		    ),

	     	 array(
                'id'       => "{$prefix}use_gird",
                'name'    => esc_html__( 'Show Gird', 'snsnitan' ),
                'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'0' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '0',
            ),

			array(
				'name'    => esc_html__( 'Header Style', 'snsnitan' ),
				'id'       => "{$prefix}header_style",
				'type'     => 'select',
				'std'  => '',
				'options'  => array(
					''   	  => esc_html__( '', 'snsnitan' ),
					'style1'  => esc_html__( 'Style1', 'snsnitan' ),
					'style2'  => esc_html__( 'Style2', 'snsnitan' ),
					'style3'  => esc_html__( 'Style3', 'snsnitan' ),
					'style4'  => esc_html__( 'Style4', 'snsnitan' ),
				),
				'desc'		=> esc_html__('Select Header style. ', 'snsnitan'),
			),
			array(
				'name' => esc_html__( 'Top Header Background', 'snsnitan' ),
				'id'   => "{$prefix}topheader_bg_color",
				'type' => 'color',
				 'default'  => '#333333',
				'desc' => esc_html__( 'It will priority than Top Header Background in Theme Option panel', 'snsnitan' ),
			),
			array(
				'name' => esc_html__( 'Show header advertisement', 'snsnitan' ),
				'id'   => "{$prefix}show_advertisement",
				'type' => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '2',
				'desc' => esc_html__( 'It will priority than in Theme Option panel', 'snsnitan' ),
			),
			array(
				'name'    => esc_html__( 'Show Title', 'snsnitan' ),
				'id'      => "{$prefix}showtitle",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '1',
			),
			array(
				'name' => esc_html__( ' Header Background Color', 'snsnitan' ),
				'id'   => "{$prefix}header_bg_color",
				'type' => 'color',
				'desc' => esc_html__( 'It will priority than Header Background in Theme Option panel', 'snsnitan' ),
			),
			
			 array(
			 	'name'    => esc_html__( 'Logo', 'snsnitan' ),
			 	'id'       => "{$prefix}header_logo",
		       'type'    => 'image_advanced',
		        'default'	=> '',
		        'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
		    ),
			 array(
                'id'       => "{$prefix}number_column_footer",
                'type'     => 'select',  
                'name'    => esc_html__( 'Display Number Column in Footer', 'snsnitan' ),
                'options'  => array(

                	''   	=> esc_html__( "", "snsnitan" ),
                    '1'   	=> esc_html__( "1 Column", "snsnitan" ),
                    '2'   	=> esc_html__( "2 Column", "snsnitan" ),	 
                    '3'   	=> esc_html__( "3 Column", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "4 Column", "snsnitan" ),
                    '5-style1'   	=> esc_html__( "5 Column - style 1", "snsnitan" ),	
                    '5-style2'   	=> esc_html__( "5 Column - style 2", "snsnitan" ),
                    '6'   	=> esc_html__( "6 Column", "snsnitan" ),	                   	                      

                ),
                'subtitle' => esc_html__( 'Developed from grid for bootstap', 'snsnitan' ),
                 'std'  => '',                  	
            ),
            array(
                'id'       => "{$prefix}footer_column_1",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 1', 'snsnitan' ),
                'options'  => array(
                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	
                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
                    '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                   	                      
                ),
                'std'  => '8',
                        	
            ),

            array(
                'id'       => "{$prefix}footer_column_2",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 2', 'snsnitan' ),
                'options'  => array(
                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),	                   	                      
                ),
                'std'  => '1',      	
            ),

            array(
                'id'       => "{$prefix}footer_column_3",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 3', 'snsnitan' ),
                'options'  => array(
                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	 
                     '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
                    '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),              	                      
                ),
                 'std'  => '2',        	
            ),

            array(
                'id'       => "{$prefix}footer_column_4",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 4', 'snsnitan' ),
                'options'  => array(
                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),	                   	                      
                ),
                 'std'  => '3',       	
            ),

            array(
                'id'       => "{$prefix}footer_column_5",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 5', 'snsnitan' ),
                'options'  => array(
                   	'1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	
                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ), 
                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                	                      
                ),
                 'std'  => '4',       	
            ),

            array(
                'id'       => "{$prefix}footer_column_6",
                'type'     => 'select',  
                'name'    => esc_html__( 'Column 6', 'snsnitan' ),
                'options'  => array(
                   	'1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                  	                      
                ),
                 'std'  => '5',        	
            ),


			array(
				'name' => esc_html__( 'Footer background image', 'snsnitan' ),
				'id'   => "{$prefix}footer_img",
				'type' => 'image_advanced',
				 'default'  => '',
				'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
			),
			 array(
		        'id'		=> "{$prefix}footer_border_size",
		        'type'		=> 'text',
		        'name'		=> esc_html__( 'Footer border size', 'snsnitan' ),
		    	'default'  => '0px',
		    	//'transparent'	=> false
		    ),
		     array(
		        'id'		=> "{$prefix}footer_border_color",
		        'type'		=> 'color',
		        'name'		=> esc_html__( 'Footer border color', 'snsnitan' ),
		    	'default'  => '#eaeaea',
		    	//'transparent'	=> false
		    ),
			array(
				'name' => esc_html__( 'Top Footer Background', 'snsnitan' ),
				'id'   => "{$prefix}topfooter_bg_color",
				'type' => 'color',
				 'default'  => '#f5f5f5',
				'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
			),
			array(
				'name' => esc_html__( 'Bottom Footer Background', 'snsnitan' ),
				'id'   => "{$prefix}bottomfooter_bg_color",
				'type' => 'color',
				 'default'  => '#ffffff',
				'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
			),
			array(
				'name' => esc_html__( 'Footer title color', 'snsnitan' ),
				'id'   => "{$prefix}footer_title_color",
				'type' => 'color',
				  'default'  => '#ffffff',
				'desc' => esc_html__( 'It priority more in theme option', 'snsnitan' ),	
			),

			array(
				'name'    => esc_html__( 'Main Navigation Menu', 'snsnitan' ),
				'id'       => "{$prefix}main_menu",
				'type'     => 'select',
				'std'  => 'def',
				'options'  => $menu_options,
				'desc' => esc_html__( 'Select which main menu displays on this page.', 'snsnitan' ),
			),
			array(
				'name'    => esc_html__( 'Show Title', 'snsnitan' ),
				'id'      => "{$prefix}showtitle",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '1',
			),
			array(
				'name'    => esc_html__( 'Use Slideshow', 'snsnitan' ),
				'id'      => "{$prefix}useslideshow",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '2',
			),
			array(
				'name'    => esc_html__( 'Select Slideshow', 'snsnitan' ),
				'id'      => "{$prefix}revolutionslider",
				'type'    => 'select',
				'options' =>  $revsliders ,
				'std'         => '',
			),
			array(
				'name'    => esc_html__( 'Show Breadcrumbs', 'snsnitan' ),
				'id'      => "{$prefix}showbreadcrump",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '1',
				'desc' => esc_html__( 'Dont apply for Front page. Because breadcrumbs dont sense in Front page.', 'snsnitan' ),
			),
			

			array(
				'name' => esc_html__( 'Custom Background for Breadcrumbs', 'snsnitan' ),
				'id'   => "{$prefix}bg_breadcrump",
				'type' => 'image_advanced',
				 'default'  => '',
			//	'max_file_uploads' => 1,
				//'desc' => esc_html__( 'Default value in theme option - SNS Theme', 'snsnitan' ),
			),
			
			array(
				'name'    => esc_html__( 'Config Theme Color for this page?', 'snsnitan' ),
				'id'      => "{$prefix}page_themecolor",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsnitan' ),
					'2' => esc_html__( 'No', 'snsnitan' ),
				),
				'std'         => '2',
			),
			array(
				'name' => esc_html__( 'Sellect Theme Color', 'snsnitan' ),
				'id'   => "{$prefix}theme_color",
				'type' => 'color',
				'desc' => esc_html__( 'It will priority than Theme Color in Theme Option panel', 'snsnitan' ),
			),
		)
	);
	// Post format - Gallery
	$meta_boxes[] = array(
	    	'id' => 'sns-post-gallery',
		    'title' =>  esc_html__('Gallery Settings','snsnitan'),
	    	'description' => '',
    		'pages'      => array( 'post' ), // Post type
	    	'context'    => 'normal',
		    'priority'   => 'high',
	    	'fields' => array(
			     array(
			        'name'		=> 'Gallery Images',
			        'desc'	    => 'Upload Images for post Gallery ( Limit is 15 Images ).',
			        'type'      => 'image_advanced',
			        'id'	    => "{$prefix}post_gallery",
	         		'max_file_uploads' => 15 
	        	)
			)
	);
	// Post format - Video
    $meta_boxes[] = array(
		'id' => 'sns-post-video',
		'title' => esc_html__('Featured Video','snsnitan'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_video",
				'name'  => esc_html__( 'Video', 'snsnitan' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - Audio
    $meta_boxes[] = array(
		'id' => 'sns-post-audio',
		'title' => esc_html__('Featured Audio','snsnitan'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_audio",
				'name'  => esc_html__( 'Audio', 'snsnitan' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - quote
    $meta_boxes[] = array(
		'id' => 'sns-post-quote',
		'title' => esc_html__('Featured Quote','snsnitan'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_quotecontent",
				'name'  => esc_html__( 'Quote Content', 'snsnitan' ),
				'type'  => 'textarea',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_quoteauthor",
				'name'    => esc_html__( 'Quote author', 'snsnitan' ),
				'type'    => 'text',
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_quote_bg",
				'name'    => esc_html__( 'Quote Background Color', 'snsnitan' ),
				'type'    => 'color',
				'std'         => '#f5f5f5',
			),
			array(
				'id'      => "{$prefix}post_quote_color",
				'name'    => esc_html__( 'Quote Text Color', 'snsnitan' ),
				'type'    => 'color',
				'std'         => '#888888',
			),
		)
	);
	// Post format - Link
    $meta_boxes[] = array(
		'id' => 'sns-post-link',
		'title' => esc_html__('Link Settings','snsnitan'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_linkurl",
				'name'  => esc_html__( 'Link URL', 'snsnitan' ),
				'type'  => 'text',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_linktitle",
				'name'    => esc_html__( 'Link Title', 'snsnitan' ),
				'type'    => 'text',
				'clone' => false,
			),
		)
	);
	// Brand config
	$meta_boxes[] = array(
		'id'         => 'sns_brandconfig',
		'title'      => esc_html__( 'Brand Config', 'snsnitan' ),
		'post_types' => array( 'brand' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Link for brand', 'snsnitan' ),
				'id'      => "{$prefix}brandlink",
				'type'    => 'text'
			),
		)
	);

	// Testimonial config
	$meta_boxes[] = array(
		'id'         => 'sns_testimonialconfig',
		'title'      => esc_html__( 'Job', 'snsnitan' ),
		'post_types' => array( 'testimonial' ),
		'context'    => 'normal',
		//'priority'   => 'high',
		'fields'     => array(
			array(
				'id'      => "{$prefix}testimonialjob",
				'type'    => 'text'
			),
		)
	);

	return $meta_boxes;
}


if ( class_exists( 'RWMB_Field' ) ) {
	class RWMB_Layouttype_Field extends RWMB_Select_Field {
		static function admin_enqueue_scripts(){
			wp_enqueue_style( 'sns-imgselect', SNSNITAN_THEME_URI . '/framework/meta-box/img-select.css' );
		}
	}
}
