<?php
if ( ! class_exists( 'snsnitan_Options' ) ) {
class snsnitan_Options {
	public $args = array();
	public $sections = array();
	public $theme;
	public $ReduxFramework;

	public function __construct() {
		if ( ! class_exists( 'ReduxFramework' ) ) {
		 return;
		}
		if ( true == Redux_Helpers::isTheme( SNSNITAN_THEME_DIR . '/framework/sns-options.php' ) ) {
			$this->initSettings();
		} else {
			add_action( 'plugins_loaded', array( $this, 'initSettings' ), 10 );
		}
	}

	public function initSettings() {
	    // Set the default arguments
	    $this->setArguments();
	    // Set a few help tabs so you can see how it's done
	    $this->setHelpTabs();
	    // Create the sections and fields
	    $this->setSections();
	    if ( ! isset( $this->args['opt_name'] ) ) {
	        return;
	    }
	    $this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
	}

	public function setArguments() {
	    $theme = wp_get_theme();
	    $this->args = array(
            'opt_name'  			=> 'snsnitan_themeoptions',
            'display_name' 			=> $theme->get( 'Name' ),
            'display_version' 		=> $theme->get( 'Version' ),
            'menu_type'          	=> 'menu',
	        'allow_sub_menu'     	=> true,
	        'menu_title'         	=> esc_html__( 'SNS Nitan', 'snsnitan' ),
	        'page_title'         	=> esc_html__( 'SNS Nitan', 'snsnitan' ),
	        'customizer' 			=> true,
	        'page_priority'      	=> 50,
	        'menu_icon' 			=> '',
	        'hints'              	=> array(
	            'icon'          => 'icon-question-sign',
	            'icon_position' => 'right',
	            'icon_color'    => 'lightgray',
	            'icon_size'     => 'normal',
	            'tip_style'     => array(
	                'color'   	=> 'light',
	                'shadow'  	=> true,
	                'rounded' 	=> false,
	                'style'   	=> '',
	            ),
	            'tip_position'  => array(
	                'my' => 'top left',
	                'at' => 'bottom right',
	            ),
	            'tip_effect'    => array(
	                'show' => array(
	                    'effect'   => 'slide',
	                    'duration' => '500',
	                    'event'    => 'mouseover',
	                ),
	                'hide' => array(
	                    'effect'   => 'slide',
	                    'duration' => '500',
	                    'event'    => 'click mouseleave',
	                ),
	            ),
	        ),
	        'dev_mode' 				=> false,
	        //'forced_dev_mode_off'	=> false,
	        'show_options_object'   => false
	    );
	}

	public function setHelpTabs() {
	    $this->args['help_tabs'][] = array(
	        'id'      => 'redux-help-tab-1',
	        'title'   => esc_html__( 'Theme Information 1', 'snsnitan' ),
	        'content' => wp_kses(__( '<p>This is the tab content, HTML is allowed.</p>', 'snsnitan' ), array(
							'p' => array()
						 ))
	    );
	    $this->args['help_tabs'][] = array(
	        'id'      => 'redux-help-tab-2',
	        'title'   => esc_html__( 'Theme Information 2', 'snsnitan' ),
	        'content' => wp_kses(__( '<p>This is the tab content, HTML is allowed.</p>', 'snsnitan' ), array(
							'p' => array()
						 ))
	    );
	    $this->args['help_sidebar'] = wp_kses(__( '<p>This is the sidebar content, HTML is allowed.</p>', 'snsnitan' ), array(
										'p' => array()
									  ));
	}
	public function setSections() {
		$this->sections[] = $this->importSampleData();
	    $this->sections[] = $this->getGeneralCfg();
	    $this->sections[] = $this->getHeaderCfg();
	    $this->sections[] = $this->getFooterCfg();
	    $this->sections[] = $this->getBlogCfg();
	    $this->sections[] = $this->getPageNotFoundCfg();
	    $this->sections[] = $this->getWooCfg();
	    $this->sections[] = $this->getAdvanceCfg();
	}
	public function importSampleData(){
		$desc = ''; $i_message = '';
		if ( ! function_exists( 'is_plugin_active' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
        }
        if( !is_plugin_active('wordpress-importer/wordpress-importer.php') ){
        	$i_message .= '<li><i class="fa fa-angle-double-right"></i> Need install and active plugin <a href="https://wordpress.org/plugins/wordpress-importer/" target="_blank">Wordpress Importer</a></li>';
        }
        if( !defined('WP_LOAD_IMPORTERS') ){
        	$i_message .= "<li><i class='fa fa-angle-double-right'></i> Need add <code>define('WP_LOAD_IMPORTERS', true);</code> to file wp-config.php</li>";
        }
        if ( $i_message !='' ){
        	$subtitle = '
				<p><label><i class="fa fa-exclamation-circle"></i>  Please follow the check list bellow to enable import function:</label></p>
				<ul class="i_message">'.$i_message.'</ul>
			';
        }else{
        	$subtitle = '<div class=\'button\' id=\'btn_sampledata\'>Import</div>';
        	$subtitle .= '
		    	<div class=\'sns-importprocess\'>
		    		<div  class=\'sns-importprocess-width\'></div>
		    	</div>
		    	<span id=\'sns-importmsg\'><span class=\'status\'></span></span>
	    		<div id="sns-import-tablecontent">
					<label>List contents will import:</label>
					<ul>
					  <li class="theme-cfg"><i class="fa fa-hand-pointer-o"></i>Theme config</li>
					  <li class="revslider-cfg"><i class="fa fa-hand-pointer-o"></i>Revolution Slider config</li>
					  <li class="all-content"><i class="fa fa-hand-pointer-o"></i>All contents</li>
					  <li class="widget-cfg"><i class="fa fa-hand-pointer-o"></i>Widget config</li>
					</ul>
				</div>
	    	';
        }
		return  array(
		    'icon' => 'el-icon-briefcase',
		    'title' => esc_html__('Demo content', 'snsnitan'),
		    'fields' => array(
		        array(
		        	'title' => '',
		            'subtitle' => $subtitle,
		            'desc'	=> $desc,
		            'id' => 'theme_data',
		            'icon' => true,
		            'type' => 'image_select',
		            'default' => 'sns_nitan',
		            'options' => array(
		                'sns_logo' => get_template_directory_uri().'/assets/img/logo.png',
		            ),
		        )
		    )
		);
	}
	public function getGeneralCfg() {
	    return array(
	        'title'		=> esc_html__( 'General', 'snsnitan' ),
	        'icon'		=> 'el-icon-cog',
	        'fields'	=> array(
	            array(
	                'id'       => 'theme_color',
	                'type'     => 'color',
	                'output'   => array( '.site-title' ),
	                'title'    => esc_html__( 'Theme Color', 'snsnitan' ),
	                'default'  => '#e22020',
	        		'transparent'	=> false
	            ),
	             array(
	                'id'       => 'fullwidth',
	                'type'     => 'switch',
	                'title'    => 'Full Width For Body',
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	            array(
	                'id'       => 'use_boxedlayout',
	                'type'     => 'switch',
	                'title'    => 'Use Boxed Layout',
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	            array(
	                'id'       => 'body_bg',
	                'type'     => 'background',
	                'output'   => array( 'body' ),
	                'title'    => 'Body Background',
	                'background-image' => false,
	        		'preview'	=> false,
	        		'required' => array( 'use_boxedlayout', '=', '1' )
	            ),
	            array(
	                'id'       => 'body_bg_type',
	                'type'     => 'select',
	                'title'    => 'Body Background Image',
	                'options'  => array(
	                    'none'   	=> 'No image',
	                    'img'  		=> 'Image',
	                ),
	                'default'  => 'img',
	                'select2'  => array( 'allowClear' => false ),
	                'required' => array( 'use_boxedlayout', '=', '1' )
	            ),
			    array(
			        'id'		=> 'body_bg_type_img',
			        'type'		=> 'media',
			        'title'		=> esc_html__( 'Body Background type img', 'snsnitan' ),
			         'default'	=> '',
			        'title'    => 'Body Background type img',
              	 	'required' => array( 'body_bg_type', '=', array( 'img' ) ),
			    ),
			     array(
	                'id'       => 'use_gird',
	                'title'    => 'Show Gird',  
	                'type'     => 'switch',
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	        		'required' => array( 'use_boxedlayout', '=', '1' )
	            ),
	            array(
	                'id'          => 'body_font',
	                'type'        => 'typography',
	                'title'       => esc_html__( 'Body font', 'snsnitan' ),
	                'line-height'   => false,
	                'text-align'   => false,
	                'color'         => true,
	                'all_styles'  => true,
	                'units'       => 'px',
	                // 'subsets'       => true,
	                'default'     => array(
	                    'font-size'   => '14px',
	                    'font-family' => 'Lato',
	                    'font-weight' => '400',
	                    'color'		  => '#888888'
	                ),
	            ),
	            array(
	                'id'          => 'secondary_font',
	                'type'        => 'typography',
	                'title'       => esc_html__( 'Secondary font', 'snsnitan' ),
	                'line-height'   => false,
	                'text-align'   => false,
	                'color'         => false,
	                'all_styles'  => true,
	                'units'       => 'px',
                	'font-size'     => false,
	                // 'subsets'       => true,
	                'default'     => array(
	                    'font-family' => 'Open Sans',
	                    'font-weight' => '400',
	                ),
	            ),
	            array(
	                'id'       => 'secondary_font_target',
	                'type'     => 'textarea',
	                'title'    => esc_html__( 'Secondary font target', 'snsnitan' ),
	                'default'  => '.sns-latest-posts.style_1 .date-blog .day, .sns-latest-posts.style_1 .date-blog .month, .sns-products-slider .sns-products-slider-content .item-slider-countdown .sns_sale_clock > div > span, .sns-products-slider.left .sns-products-slider-content .item-slider-title .product_title a',
	                'validate' => 'no_html'
	            ),
	           

	             array(
	                'id'       => 'showbreadcrump',
	                'type'     => 'switch',
	                'title'    => 'Show Breadcrumbs',
	                'default'  => true,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	             array(
			        'id'		=> 'bg_breadcrump',
			        'type'		=> 'media',
			        'default'	=> '',
			        'title'		=> esc_html__( 'Custom Background for Breadcrumbs', 'snsnitan' ),
			    ),
	        )
	    );
	}
	public function getHeaderCfg() {
	    return array(
	        'title'		=> esc_html__( 'Header', 'snsnitan' ),
	        'icon'		=> 'el el-brush',
	        'fields'	=> array(
	        	array(
	        		'id'       => 'header_style',
	        		'type' => 'select',
	        		
	        		'title'    => esc_html__( 'Header Style', 'snsnitan' ),
	        		'default'  => 'style2',
	        		'options' => array(
						'style1' 				=> esc_html__( 'Style1', 'snsnitan'),
						'style2' 				=> esc_html__( 'Style2', 'snsnitan'),
						'style3' 				=> esc_html__( 'Style3', 'snsnitan'),
						'style4' 				=> esc_html__( 'Style4', 'snsnitan'),
					),
					'desc'		=> esc_html__( 'Select Header Style', 'snsnitan' ),
	        		
	        	),
	        	 array(
	                'id'       => 'topheader_bg_color',
	                'type'     => 'color',
	                
	                'title'    => esc_html__( 'Top Header Background', 'snsnitan' ),
	                'default'  => '#333333',
	        		'transparent'	=> false,
	        		'required' => array( 'header_style', '=', 'style3' ) 	
	            ),
	        	
	        	array(
	        		 'title'    => esc_html__( 'Show header advertisement', 'snsnitan' ),
					'id'       => 'show_advertisement',
					'type' => 'switch',
					'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
                     'required' => array( 'header_style', '=', 'style4' ) 	
				),
	        	array(
	                'id'       => 'header_bg_color',
	                'type'     => 'color',      
	                'title'    => esc_html__( 'Header Background Color', 'snsnitan' ),
	                'default'  => '#ffffff',
	        		'transparent'	=> false
	            ),
			    array(
			        'id'		=> 'header_logo',
			        'type'		=> 'media',
			        'default'	=> '',
			        'title'		=> esc_html__( 'Logo', 'snsnitan' ),
                	'subtitle' => esc_html__( 'If this is not selected, This theme will be display logo with "theme/snsnitan/img/logo.png"', 'snsnitan' ),
			        'desc'		=> esc_html__( 'Image that you want to use as logo', 'snsnitan' ),
			    ),
			     array(
			        'id'		=> 'header_logo_small',
			        'type'		=> 'media',
			        'default'	=> '',
			        'title'		=> esc_html__( 'Small Logo', 'snsnitan' ),
			        'desc'		=> esc_html__( 'used in Header style 2, priority over logo', 'snsnitan' ),
			         'required' => array( 'header_style', '=', 'style2' ) 	
			    ),
			    array(
	                'id'       => 'use_logocolor',
	                'type'     => 'switch',
	                'title'    => 'Use background-color for logo',
	                'subtitle' => esc_html__( 'Some logo image is transparent. Maybe it need background-color', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
			    array(
	                'id'       => 'use_stickmenu',
	                'type'     => 'switch',
	                'title'    => 'Enable Sticky Menu',
	                'subtitle' => esc_html__( 'Keep menu on top when scroll down/up', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
			    array(
	                'id'       => 'settings_option',
	                'type'     => 'switch',
	                'title'    => 'Enable Settings Option',
	                'subtitle' => esc_html__( 'Show / Hide the Settings button contain: Language options, Currency', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
                    'off'      => 'No',
	            ),
	        )
	    );
	}
	public function  getFooterCfg(){
		return array(
	        'title'		=> esc_html__( 'Footer', 'snsnitan' ),
	        'icon'		=> 'el el-link',
	        'fields'	=> array(
	        	array(
	                'id'       => 'number_column_footer',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Display Number Column in Footer', 'snsnitan' ),
	                'options'  => array(
	                    '1'   	=> esc_html__( "1 Column", "snsnitan" ),
	                    '2'   	=> esc_html__( "2 Column", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "3 Column", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "4 Column", "snsnitan" ),
	                    '5-style1'   	=> esc_html__( "5 Column - style 1", "snsnitan" ),	
	                    '5-style2'   	=> esc_html__( "5 Column - style 2", "snsnitan" ),
	                    '6'   	=> esc_html__( "6 Column", "snsnitan" ),	                   	                      

	                ),
	                'subtitle' => esc_html__( 'Developed from grid for bootstap', 'snsnitan' ),
	                'default'  => '5-style1',	                     	
	            ),
	            array(
	                'id'       => 'footer_column_1',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 1', 'snsnitan' ),
	                'options'  => array(
	                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	
	                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
	                    '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                   	                      
	                ),
	                
	                'default'  => '8',	
	                        	
	            ),

	            array(
	                'id'       => 'footer_column_2',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 2', 'snsnitan' ),
	                'options'  => array(
	                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
	                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
	                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),	                   	                      
	                ),
	                
	                'default'  => '1',	
	                'required' => array( 'number_column_footer', '>=', '2' ),	        	
	            ),

	            array(
	                'id'       => 'footer_column_3',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 3', 'snsnitan' ),
	                'options'  => array(
	                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	 
	                     '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
	                    '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),              	                      
	                ),
	                
	                'default'  => '2',	
	                'required' => array(  'number_column_footer', '>=', '3' )	        	
	            ),

	            array(
	                'id'       => 'footer_column_4',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 4', 'snsnitan' ),
	                'options'  => array(
	                    '1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
	                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
	                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),	                   	                      
	                ),
	                
	                'default'  => '3',	
	                'required' => array(  'number_column_footer', '>=', '4' )	        	
	            ),

	            array(
	                'id'       => 'footer_column_5',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 5', 'snsnitan' ),
	                'options'  => array(
	                   	'1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),	
	                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ), 
	                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                	                      
	                ),
	                
	                'default'  => '4',	
	                'required' => array(  'number_column_footer', '>=', '5' )	        	
	            ),

	            array(
	                'id'       => 'footer_column_6',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Column 6', 'snsnitan' ),
	                'options'  => array(
	                   	'1'   	=> esc_html__( "Footer Links #1", "snsnitan" ),
	                    '2'   	=> esc_html__( "Footer Links #2", "snsnitan" ),	 
	                    '3'   	=> esc_html__( "Footer Links #3", "snsnitan" ),	                   	                      
	                    '4'   	=> esc_html__( "Footer Links #4", "snsnitan" ),	                   	                      
	                    '5'   	=> esc_html__( "Footer Links #5", "snsnitan" ),
	                    '6'   	=> esc_html__( "Footer Links #6", "snsnitan" ),
	                    '7'   	=> esc_html__( "Footer Links #7", "snsnitan" ),
	                   '8'   	=> esc_html__( "Footer Links #8", "snsnitan" ),
	                    '9'   	=> esc_html__( "Footer Links #9", "snsnitan" ),                  	                      
	                ),
	                
	                'default'  => '5',	
	                'required' => array(  'number_column_footer', '>=', '6' )	        	
	            ),
	        	array(
			        'id'		=> 'footer_img',
			        'type'		=> 'media',
			        'title'		=> esc_html__( "Footer background image", 'snsnitan' ),
			    	
			    ),
			     array(
			        'id'		=> 'footer_border_size',
			        'type'		=> 'text',
			        'title'		=> esc_html__( "Footer border size", 'snsnitan' ),
			    	'default'  => '0px',
			    	//'transparent'	=> false
			    ),
			     array(
			        'id'		=> 'footer_border_color',
			        'type'		=> 'color',
			        'title'		=> esc_html__( "Footer border color", 'snsnitan' ),
			    	'default'  => '#eaeaea',
			    	'transparent'	=> false
			    ),
			    array(
			        'id'		=> 'topfooter_bg_color',
			        'type'		=> 'color',
			        'title'		=> esc_html__( "Top Footer Background", 'snsnitan' ),
			    	'default'  => '#f5f5f5',
			    	'transparent'	=> false
			    ),
			    
			    array(
			        'id'		=> 'bottomfooter_bg_color',
			        'type'		=> 'color',
			        'title'		=> esc_html__( "Bottom Footer Background", 'snsnitan' ),
			    	'transparent'	=> false
			    ),
			     array(
			        'id'		=> 'footer_title_color',
			        'type'		=> 'color',
			        'title'		=> esc_html__( "Footer title color", 'snsnitan' ),
			    	 'default'  => '#ffffff',
			    	 'transparent'	=> false
			    ),
			    array(
			        'id'		=> 'payment_img',
			        'type'		=> 'media',
			        'title'		=> esc_html__( "Payment method's image", 'snsnitan' ),
			    	'default'	=> get_template_directory_uri() . '/assets/img/default/payment.png',
			    ),
			    array(
			        'id'		=> 'copyright',
			        'type'		=> 'textarea',
			        'title'		=> esc_html__( "Copyright", 'snsnitan' ),
			        'default' => esc_html__( "Designed by SNSTheme.Com", 'snsnitan' ),
			    ),
	        )
	    );
	}
	public function getBlogCfg() {
		$siderbars = array(
		    'widget-area' => esc_html__( 'Main Sidebar', 'snsnitan' ),
		    'right-sidebar' => esc_html__( 'Right Sidebar', 'snsnitan' ),
			'left-sidebar' => esc_html__( 'Left Sidebar', 'snsnitan' ),
			'product-sidebar' => esc_html__( 'Product Sidebar', 'snsnitan' ),
			'woo-sidebar' => esc_html__( 'Woo Sidebar', 'snsnitan' ),
		);
		//if( is_admin() ) wp_enqueue_style('sns-admin-css', SNSNITAN_THEME_URI . '/assets/css/admin-theme-option.css');
	    return array(
	        'title'		=> esc_html__( 'Blog', 'snsnitan' ),
	        'icon'		=> 'el el-file-edit',
	        'fields'	=> array(
				array(
				    'id'       => 'layouttype',
				    'type'     => 'image_select',
				    'title'    => esc_html__('Default Blog Layout', 'snsnitan'), 
				    'options'  => array(
				        'm'      => array(
				            'alt'   => esc_html__( 'Without Sidebar', 'snsnitan' ), 
				            'img'   => SNSNITAN_THEME_URI.'/assets/img/admin/m.jpg'
				        ),
				        'l-m'      => array(
				            'alt'   => esc_html__( 'Use Left Sidebar', 'snsnitan' ), 
				            'img'   => SNSNITAN_THEME_URI.'/assets/img/admin/l-m.jpg'
				        ),
				        'm-r'      => array(
				            'alt'  => esc_html__( 'Use Right Sidebar', 'snsnitan' ), 
				            'img'  => SNSNITAN_THEME_URI.'/assets/img/admin/m-r.jpg'
				        ),
				        // 'l-m-r'      => array(
				        //     'alt'   => esc_html__( 'Use Left & Right Sidebar', 'snsnitan' ), 
				        //     'img'   => SNSNITAN_THEME_URI.'/assets/img/admin/l-m-r.jpg'
				        // )
				    ),
				    'default' => 'm-r'
				),
				// Left Sidebar
				array(
					'title'  => esc_html__( 'Left Sidebar', 'snsnitan' ),
					'id'    => "leftsidebar",
					//'desc'  => esc_html__( 'Text description', 'snsnitan' ),
					'type'  => 'select',
					'options'	=> $siderbars,
					'multiselect'	=> false,
					'required' => array( 'layouttype', '=', array( 'l-m', 'l-m-r' ) )
				),
				// Right Sidebar
				array(
					'title'  => esc_html__( 'Right Sidebar', 'snsnitan' ),
					'id'    => "rightsidebar",
					//'desc'  => esc_html__( 'Text description', 'snsnitan' ),
					'type'  => 'select',
					'options'	=> $siderbars,
					'multiselect'	=> false,
					'required' => array( 'layouttype', '=', array( 'm-r', 'l-m-r' ) )
				),
				array( 
		        	'title' => esc_html__( 'Blog Style', 'snsnitan'),
					'id' => 'blog_type',
					'default' => '',
					'type' => 'select',
					'multiselect' => false ,
					'options' => array(
						'' 				=> esc_html__( 'Blog Layout 1', 'snsnitan'),
						'layout2' 		=> esc_html__( 'Blog Layout 2', 'snsnitan'),
						'masonry' 		=> esc_html__( 'Masonry', 'snsnitan'),
					)
				),
				// array(
	   //              'id'       => 'blog_gridcol',
	   //              'type'     => 'select',
	   //              'title'    => esc_html__( 'Grid columns', 'snsnitan' ),
	   //              'subtitle'  => esc_html__( 'We are using grid bootstap - 12 cols layout', 'snsnitan' ),
	   //              'default'  => '3',
	   //              'options'  => array(
	   //                  '2' => '2',
	   //                  '3' => '3',
	   //                  '4' => '4',
	   //                  '6' => '6',
	   //              ),
	   //              'required' => array( 'blog_type', '=', array( 'grid' ) )
	   //          ),
	   //          array(
	   //              'id'       => 'blog_enablemasonry',
	   //              'type'     => 'switch',
	   //              'title'    => esc_html__( 'Enable Masonry', 'snsnitan' ),
	   //              'default'  => true,
	   //              'on'       => 'Yes',
	   //              'off'      => 'No',
	   //              'required' => array( 'blog_type', '=', array( 'grid' ) )
	   //          ),
	   //          array(
	   //              'id'       => 'blog_pagination',
	   //              'type'     => 'select',
	   //              'title'    => esc_html__( 'Blog Pagination', 'snsnitan' ),
	   //              'default'  => '',
	   //              'options'  => array(
	   //                  '' => 'Standard',
	   //                  'infinite' => 'Infinite Scroll',
	   //                  'loadmore' => 'Load More Button'
	   //              ),
	   //              'required' => array( 'blog_type', '=', array( 'grid' ) )
	   //          ),
				array(
				    'id'   =>'divider_blog',
				    'type' => 'divide'
				),
	            array(
	                'id'       => 'show_categories',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Categories for Blog Entries Page', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	        	array(
	        		'id'       => 'show_date',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show Date for Blog Entries Page', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	/*array(
	        		'id'       => 'show_view_count',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show View Count', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),*/
	            array(
	                'id'       => 'show_author',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Author for Blog Entries Page', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	        	array(
	        		'id'       => 'show_tags',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show Tags for Blog Entries Page', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	array(
	        		'id'       => 'show_comment_count',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Show Comment Count', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	array(
	        		'id'       => 'excerpt_length',
	        		'type'     => 'text',
	        		'title'    => esc_html__( 'Blog Excerpt Length', 'snsnitan' ),
	        		'default'  => '55',
	        	),
	        	array(
	        		'id'       => 'show_readmore',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Enable Read More Button', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	array(
	        		'id'       => 'tag_showmore',
	        		'type'     => 'switch',
	        		'title'    => esc_html__( 'Enable View More Tags', 'snsnitan' ),
	        		'subtitle' => esc_html__( 'Apply for widget Tag Cloud to show the number for tags display first.', 'snsnitan' ),
	        		'default'  => true,
	        		'on'       => 'Yes',
	        		'off'      => 'No',
	        	),
	        	array(
	                'id'       => 'tag_display_first',
	                'type'     => 'text',
	                'title'    => esc_html__( 'The number for Tags display first.', 'snsnitan' ),
	                'default'  => '7',
	                'required' => array( 'tag_showmore', '=', true )
	            ),

	            array(
				    'id'   =>'divider_post',
				    'type' => 'divide'
				),
	            array(
	                'id'       => 'show_postauthor',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Author Info on Post Detail', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'enalble_related',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Related Posts on Post Detail', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	        	array(
	        		'id' 		=> 'related_posts_by',
	        		'title' 	=> esc_html__( 'Related Post By', 'snsnitan'),
	        		'desc'		=> esc_html__('Get related post by Categories or Tags', 'snsnitan'),
	        		'default' 	=> 'cat',
	        		'type' 		=> 'select',
	        		'multiselect' => false ,
	        		'options'	=> array(
	        			'cat' 	=> 'Categories',
	        			'tag' 	=>  'Tags',
	        		),
	        		'required' => array( 'enalble_related', '=', true )
	        	),
	            array(
	                'id'       => 'related_num',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Related Posts Number', 'snsnitan' ),
	                'default'  => '5',
	                'required' => array( 'enalble_related', '=', true )
	            ),
	            array(
	                'id'       => 'show_postsharebox',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Share Box on Post Detail', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
				    'id'       => 'show_facebook_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Facebook in Sharing Box', 'snsnitan'),
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
	            array(
				    'id'       => 'show_twitter_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Twitter in Sharing Box', 'snsnitan'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_gplus_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show G + in Sharing Box', 'snsnitan'),
				    'required' => array( 'show_postsharebox', '=', true ), 
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_linkedin_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Linkedin in Sharing Box', 'snsnitan'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_pinterest_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Pinterest in Sharing Box', 'snsnitan'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_tumblr_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Tumblr in Sharing Box', 'snsnitan'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
				array(
				    'id'       => 'show_email_sharebox',
				    'type'     => 'checkbox',
				    'title'    => esc_html__('Show Send Email in Sharing Box', 'snsnitan'), 
				    'required' => array( 'show_postsharebox', '=', true ),
				    'default'  => '1'// 1 = on | 0 = off
				),
	        	array(
	        		'id' 		=> 'pagination',
	        		'title' 	=> esc_html__( 'Page Navigation', 'snsnitan'),
	        		'desc'		=> esc_html__('Choose Type of navigation for blog and any listing page.', 'snsnitan'),
	        		'default' 	=> 'def',
	        		'type' 		=> 'select',
	        		'multiselect' => false ,
	        		'options'	=> array(
	        			'def' 	=> esc_html__('Default PageNavi', 'snsnitan'),
	        			'ajax' 	=>  esc_html__('Ajax', 'snsnitan'),
	        		),
	        	),

	            
	        )
	    );
	}
	public function getPageNotFoundCfg(){
		return array(
			'title'		=> esc_html__( 'Page Not Found', 'snsnitan' ),
			'icon'		=> 'el el-warning-sign',
			'fields'	=> array(
				array(
	                'id'       => 'notfound_title',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Title', 'snsnitan' ),
	                'default'  => esc_html__('Page not found', 'snsnitan'),
	            ),
				array(
					'id'       => 'notfound_content',
					'type'     => 'textarea',
					'title'    => esc_html__( 'Content', 'snsnitan' ),
					'default'  => esc_html__('Sory but the page you are looking for does not exit, have been removed or name changed. Go back Homepage or enter the key words to search, please!', 'snsnitan'),
				),
			  )
			);
	}

	public function getWooCfg() {
		return array(
	        'title'		=> esc_html__( 'WooCommerce', 'snsnitan' ),
	        'icon'		=> 'el el-shopping-cart',
	        'fields'	=> array(
	        	array(
	                'id'       => 'woo_uselazyload',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Use lazyload for Product Image', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'		=> 'woo_list_modeview',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'Default mode view for listing page', 'snsnitan' ),
	                'options'  => array(
	                    'grid' => 'Grid',
	                    'list' => 'List',
	                ),
	                'default'  => 'grid'
			    ),
	            array(
	                'id'       => 'woo_grid_col',
	                'type'     => 'select',
	                'title'    => esc_html__( 'Grid columns', 'snsnitan' ),
	                'subtitle'  => esc_html__( 'We are using grid bootstap - 12 cols layout', 'snsnitan' ),
	                'default'  => '3',
	                'options'  => array(
	                    '1' => '1',
	                    '2' => '2',
	                    '3' => '3',
	                    '4' => '4',
	                    '6' => '6',
	                ),
	            ),
	            array(
	                'id'       => 'woo_number_perpage',
	                'type'     => 'text',
	                'title'    => esc_html__( 'Number products per listing page', 'snsnitan' ),
	                'default'  => '12',
	            ),
	        	
	            array(
				    'id'   =>'divider_blog',
				    'type' => 'divide'
				),
				array(
	                'id'       => 'single_product_sidebar',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Show Single Product Sidebar', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
				array(
	                'id'       => 'woo_usecloudzoom',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Cloud Zoom for Product Image', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'woo_zoomtype',
	                'type'     => 'select',  
	                'title'    => esc_html__( 'Zoom Type for Cloud Zoom', 'snsnitan' ),
	                'options'  => array(
	                    'window'   	=> 'Window',
	                    'lens'   	=> 'Lens',
	                    'inner'   	=> 'Inner',                    		                   
	                ),
	                'default'  => 'window',       
	                'required' => array( 'woo_usecloudzoom', '=', true ) 	
	            ),
	            array(
	                'id'       => 'woo_sharebox',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Share box', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	              array(
	                'id'       => 'woo_upsells',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Upsells Products', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'woo_related',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Related Products', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	            	'id'       => 'woo_related_num',
                 	'type'     => 'text',
                 	'title'    => esc_html__( 'Number Related Products to display', 'snsnitan' ),
                 	'required' => array( 'woo_related', '=', '1' ),
                 	'default'  => '6',
                ),
            
	        )
	    );
	}
	public function getAdvanceCfg() {
	    return array(
	        'title'		=> esc_html__( 'Advance', 'snsnitan' ),
	        'icon'		=> 'el el-wrench',
	        'fields'	=> array(
	            array(
	                'id'       => 'advance_tooltip',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Tooltip', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'advance_cpanel',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Cpanel', 'snsnitan' ),
	                'default'  => false,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'       => 'advance_scrolltotop',
	                'type'     => 'switch',
	                'title'    => esc_html__( 'Enable Button Scroll To Top', 'snsnitan' ),
	                'default'  => true,
	                'on'       => 'Yes',
	                'off'      => 'No',
	            ),
	            array(
	                'id'		=> 'advance_scss_compile',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'SCSS Compile', 'snsnitan' ),
	                'options'  => array(
	                    '1' => 'Only compile when don\'t have the css file',
	                    '2' => 'Alway compile'
	                ),
	                'default'  => '1'
			    ),
	            array(
	                'id'		=> 'advance_scss_format',
	                'type'		=> 'select',
	                'title'		=> esc_html__( 'CSS Format', 'snsnitan' ),
	                'options'  => array(
	                    'scss_formatter' => 'scss_formatter',
	                    'scss_formatter_nested' => 'scss_formatter_nested',
	                    'scss_formatter_compressed' => 'scss_formatter_compressed',
	                ),
	                'default'  => 'scss_formatter'
			    ),
	            array(
	                'id'       => 'advance_customcss',
	                'type'     => 'ace_editor',
	                'title'    => esc_html__( 'Custom CSS', 'snsnitan' ),
	                'subtitle' => esc_html__( 'Paste your CSS code here. EX: .class{font-size:13px}', 'snsnitan' ),
	                'mode'     => 'css',
	                'theme'    => 'monokai',
	                'default'  => ""
	            ),
	            array(
	                'id'       => 'advance_customjs',
	                'type'     => 'ace_editor',
	                'title'    => esc_html__( 'Custom JS', 'snsnitan' ),
	                'subtitle' => esc_html__( 'Enter your JS code here.', 'snsnitan' ),
	                'theme'    => 'chrome',
	                'default'  => ""
	            ),
	        )
	    );
	}
}
}

?>