<?php
define( 'SNSNITAN_THEME_DIR', get_template_directory() );
define( 'SNSNITAN_THEME_URI', get_template_directory_uri() );

// Require framework
require_once( SNSNITAN_THEME_DIR.'/framework/init.php' );
/** 
    Initialize Visual Composer in the theme.
 **/
add_action( 'vc_before_init', 'snsnitan_vcSetAsTheme' );
function snsnitan_vcSetAsTheme() {
	vc_set_as_theme(true);
}
// Initialising Visual shortcode editor
 if (class_exists('WPBakeryVisualComposerAbstract')) {
 	function snsnitan_requireVcExtend(){
 		include_once( SNSNITAN_THEME_DIR . '/vc_extend/extend-vc.php' );
 	}
 	add_action('init', 'snsnitan_requireVcExtend', 2);
 }
/** 
 *	Width of content, it's max width of content without sidebar.
 **/
if ( ! isset( $content_width ) ) { $content_width = 660; }

/** 
 *	Set base function for theme.
 **/
if ( ! function_exists( 'snsnitan_setup' ) ) {
    function snsnitan_setup() {
        global $snsnitan_opt, $snsnitan_obj;
    	// Load default theme textdomain.
        load_theme_textdomain( 'snsnitan' , SNSNITAN_THEME_DIR . '/languages' );
		// Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );
		// Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );
        // Add title-tag, it auto title of head
        add_theme_support( 'title-tag' );
        // Enable support for Post Formats.
        add_theme_support( 'post-formats',
            array(
                'video', 'audio', 'quote', 'link', 'gallery'
            )
        );
        // Register images size
        add_image_size('snsnitan_megamenu_thumb', 250, 150, true);
        add_image_size('snsnitan_blog_layout2_thumbnail_size', 720,480, true); // blog layout 2
        add_image_size('snsnitan_latest_posts', 370, 266, true);
        add_image_size('snsnitan_latest_posts_widget', 80, 53, true);
        add_image_size('snsnitan_testimonial_avatar', 120, 120, true);
        add_image_size('snsnitan_products_slider_thumb', 680, 530, false);
        add_image_size('snsnitan_woo_product_thumb', 107, 151, true);
		//Setup the WordPress core custom background & custom header feature.
         $default_background = array(
            'default-color' => '#FFF',
        );
        add_theme_support( 'custom-background', $default_background );
        $default_header = array();
        add_theme_support( 'custom-header', $default_header );
        // Register navigations
	    register_nav_menus( array(
	    	'top_navigation'  => esc_html__( 'Top navigation', 'snsnitan' ),
			'main_navigation' => esc_html__( 'Main navigation', 'snsnitan' ),
		) );
    }
    add_action ( 'after_setup_theme', 'snsnitan_setup' );
}
add_action( 'after_setup_theme', 'snsnitan_woocommerce_support' );
function snsnitan_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

/** 
    Add class for body
 **/
add_filter( 'body_class', 'snsnitan_bodyclass' );
function snsnitan_bodyclass( $classes ) {
    if ( snsnitan_themeoption('use_boxedlayout', 0) == 1) {
        $classes[] = 'boxed-layout';
    }
    if( snsnitan_themeoption('advance_tooltip', 1) == 1){
        $classes[] = 'use-tooltip';
    }
    if( snsnitan_themeoption('use_stickmenu') == 1){
        $classes[] = 'use_stickmenu';
    }
    if( snsnitan_themeoption('use_logocolor', 0) == 1){
        $classes[] = 'use_logocolor';
    }
    if ( snsnitan_themeoption('woo_uselazyload') == 1 ){
        $classes[] = 'use_lazyload';
    }
    if( snsnitan_metabox('snsnitan_fullwidth') ==1 ){
        $classes[] = 'fullwidth';
    }
    if( snsnitan_metabox('snsnitan_show_advertisement') ==1 ){
        $classes[] = 'show_advertisement';
    }
    $snsnitan_headerStyle = snsnitan_themeoption('header_style', 'style2');
    if( snsnitan_metabox('snsnitan_header_style') !='' ){
        $snsnitan_headerStyle = snsnitan_metabox('snsnitan_header_style');
    }
    $classes[] = 'sns_header_' . $snsnitan_headerStyle;
     if ( snsnitan_themeoption('use_gird', 0) == 1) {
        $classes[] = 'use_gird';
    }
    if(class_exists('WooCommerce')){
        $classes[] = 'woocommerce';
    }
    return $classes;
}

function snsnitan_widgetlocations(){
    // Register widgetized locations
    if(function_exists('register_sidebar')) {
        register_sidebar(array(
           'name' => esc_html__('Main Area', 'snsnitan'),
           'id'   => 'widget-area',
            'description'   => esc_html__( 'These are widgets for the Widget Area.','snsnitan' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
           'name' => esc_html__('Top Advertisement', 'snsnitan'),
           'id'   => 'top-advertisement',
            'description'   => esc_html__( 'These are widgets for the Top Advertisement.','snsnitan' ),
            'before_widget' => '<div class="top-advertisement-widget">',
            'after_widget'  => '</div>', 
        ));
         register_sidebar(array(
           'name' => esc_html__('Header Top Left', 'snsnitan'),
           'id'   => 'top_left',
            'description'   => esc_html__( 'These are widgets for the Top Advertisement.','snsnitan' ),
            'before_widget' => '<div class="top_left">',
            'after_widget'  => '</div>', 
        ));
        register_sidebar(array(
	        'name' => esc_html__('Menu Sidebar #1', 'snsnitan'),
	        'id'   => 'menu_sidebar_1',
	        'description'   => esc_html__( 'These are widgets for Mega Menu Columns style. This sidebar displayed in the right of column.','snsnitan' ),
	        'before_widget' => '<div class="sidebar-menu-widget %2$s">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h4 class="hide">',
	        'after_title'   => '</h4>'
        ));
        
        register_sidebar(array(
	        'name' => esc_html__('Menu Sidebar #2', 'snsnitan'),
	        'id'   => 'menu_sidebar_2',
	        'description'   => esc_html__( 'These are widgets for Mega Menu Columns style. This sidebar displayed in the bottom of column.','snsnitan' ),
	        'before_widget' => '<div class="sidebar-menu-widget %2$s">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h4 class="hide">',
	        'after_title'   => '</h4>'
        ));
      
        register_sidebar(array(
           'name' => esc_html__('Footer Links #1', 'snsnitan'),
           'id'   => 'footer-links-1',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));

        register_sidebar(array(
           'name' => esc_html__('Footer Links #2', 'snsnitan'),
           'id'   => 'footer-links-2',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));

         register_sidebar(array(
           'name' => esc_html__('Footer Links #3', 'snsnitan'),
           'id'   => 'footer-links-3',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));

        register_sidebar(array(
           'name' => esc_html__('Footer Links #4', 'snsnitan'),
           'id'   => 'footer-links-4',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));
        register_sidebar(array(
           'name' => esc_html__('Footer Links #5', 'snsnitan'),
           'id'   => 'footer-links-5',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));
         register_sidebar(array(
           'name' => esc_html__('Footer Links #6', 'snsnitan'),
           'id'   => 'footer-links-6',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));
          register_sidebar(array(
           'name' => esc_html__('Footer Links #7', 'snsnitan'),
           'id'   => 'footer-links-7',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));
        register_sidebar(array(
           'name' => esc_html__('Footer Links #8', 'snsnitan'),
           'id'   => 'footer-links-8',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));
        register_sidebar(array(
           'name' => esc_html__('Footer Links #9', 'snsnitan'),
           'id'   => 'footer-links-9',
            'description'   => esc_html__( 'These are widgets for the Footer.','snsnitan' ),
            'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',       
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        ));

        register_sidebar(
            array(
            'name' => esc_html__('Right Sidebar', 'snsnitan'),
            'id' => 'right-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

        register_sidebar(
            array(
            'name' => esc_html__('Left Sidebar', 'snsnitan'),
            'id' => 'left-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
         register_sidebar(
            array(
            'name' => esc_html__('Product Sidebar', 'snsnitan'),
            'id' => 'product-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(
            array(
            'name' => esc_html__('Woo Sidebar', 'snsnitan'),
            'id' => 'woo-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
    }
}
add_action( 'widgets_init', 'snsnitan_widgetlocations' );
/** 
 *	Add styles & scripts
 **/
function snsnitan_scripts() {
	global $snsnitan_opt, $snsnitan_obj;
    $optimize = '.min';
    $optimize = '';
	// Enqueue style
	$css_file = $snsnitan_obj->snsnitan_css_file();
	wp_enqueue_style('bootstrap', SNSNITAN_THEME_URI . '/assets/css/bootstrap.min.css');
    wp_enqueue_style('owlcarousel', SNSNITAN_THEME_URI . '/assets/css/owl.carousel.min.css');
	wp_enqueue_style('fonts-awesome', SNSNITAN_THEME_URI . '/assets/fonts/awesome/css/font-awesome.min.css');
    wp_enqueue_style('fonts-awesome-animation', SNSNITAN_THEME_URI . '/assets/fonts/awesome/css/font-awesome-animation.min.css');
    wp_enqueue_style('snsnitan-ie9', SNSNITAN_THEME_URI . '/assets/css/ie9.css');
    wp_enqueue_style('snsnitan-woocommerce', SNSNITAN_THEME_URI . '/assets/css/woocommerce'.$optimize.'.css');
	wp_enqueue_style('snsnitan-theme-style', SNSNITAN_THEME_URI . '/assets/css/' . $css_file);
	
	wp_register_script('owlcarousel', SNSNITAN_THEME_URI . '/assets/js/owl.carousel.min.js', array('jquery'), '', true);
    wp_enqueue_script('owlcarousel');
	wp_register_script('masonry', SNSNITAN_THEME_URI . '/assets/js/masonry.pkgd.min.js', array('jquery'), '', true);
	wp_register_script('imagesloaded', SNSNITAN_THEME_URI . '/assets/js/imagesloaded.pkgd.min.js', array('jquery'), '', true);
	wp_register_script('countdown', SNSNITAN_THEME_URI . '/assets/countdown/jquery.countdown.min.js', array('jquery'), '2.1.0', true);
    // Enqueue script
    wp_enqueue_script('bootstrap', SNSNITAN_THEME_URI . '/assets/js/bootstrap.min.js', array('jquery'), '', true);
    wp_enqueue_script('bootstrap-tabdrop', SNSNITAN_THEME_URI . '/assets/js/bootstrap-tabdrop.min.js', array('jquery'), '', true);
    if( snsnitan_themeoption('advance_cpanel') == 1 ) wp_enqueue_script('sns-cpanel', SNSNITAN_THEME_URI . '/assets/js/sns-cpanel.js', array(), '', true);
    if( snsnitan_themeoption('woo_uselazyload') == 1 ) wp_enqueue_script('lazyload', SNSNITAN_THEME_URI . '/assets/js/jquery.lazyload'.$optimize.'.js', array(), '', true);
    wp_enqueue_script('snsnitan-script', SNSNITAN_THEME_URI . '/assets/js/sns-script'.$optimize.'.js', array('jquery'), '', true);
    // IE
    wp_enqueue_script('html5shiv', SNSNITAN_THEME_URI . '/assets/js/html5shiv.min.js', array('jquery'), '');
    wp_script_add_data('html5shiv', 'conditional', 'lt IE 9');
    wp_enqueue_script('respond', SNSNITAN_THEME_URI . '/assets/js/respond.min.js', array('jquery'), '');
    wp_script_add_data('respond', 'conditional', 'lt IE 9');
    // Add style inline with option in admin theme option
    wp_add_inline_style('snsnitan-theme-style', snsnitan_cssinline());
    // Code to embed the javascript file that makes the Ajax request
    wp_enqueue_script('ajax-request', SNSNITAN_THEME_URI . '/assets/js/ajax.js', array('jquery'));
    // Code to declare the URL to the file handing the AJAX request
    $js_params = array(
    	'ajaxurl' => admin_url( 'admin-ajax.php' )
    );
    global $wp_query, $wp;
    $js_params['query_vars'] = $wp_query->query_vars;
    $js_params['current_url'] = esc_url(home_url($wp->request));
    
    wp_localize_script('ajax-request', 'sns', $js_params);
    
}
add_action( 'wp_enqueue_scripts', 'snsnitan_scripts' );

/*
 * Enqueue admin styles and scripts
 */
function snsnitan_admin_styles_scripts(){
	wp_enqueue_style('snsnitan_admin_style', SNSNITAN_THEME_URI.'/admin/assets/css/admin-style.css');
	wp_enqueue_style( 'wp-color-picker' );
	
	wp_enqueue_media();
	wp_enqueue_script( 'wp-color-picker' );
	wp_enqueue_script('snsnitan_admin_template_js', SNSNITAN_THEME_URI.'/admin/assets/js/admin_template.js', array( 'jquery', 'wp-color-picker' ), false, true);
}
add_action('admin_enqueue_scripts', 'snsnitan_admin_styles_scripts');

// Editor style
add_editor_style('assets/css/editor-style.css');
/**
 * CSS inline
**/
function snsnitan_cssinline(){
    global $snsnitan_opt, $snsnitan_obj;
    $inline_css = '';
    // Body style
    $bodycss = '';
    if ($snsnitan_obj->snsnitan_getOption('use_boxedlayout') == 1) {
        if( $snsnitan_opt['body_bg_type'] == 'img' ){
            $bodycss .= 'background-image: url('.$snsnitan_opt['body_bg_type_img']['url'].');';
        }
    }
    if(isset($snsnitan_opt['body_font']) && is_array($snsnitan_opt['body_font'])) {
        $body_font = '';
        foreach($snsnitan_opt['body_font'] as $propety => $value)
            if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                $body_font .= $propety . ':' . $value . ';';
        
        if($body_font != '') $bodycss .= $body_font;
    }
    if (snsnitan_themeoption('body_bg-color') != '') { 
        $body_bg_color = snsnitan_themeoption('body_bg-color');
        $bodycss .= 'background-color:' .$body_bg_color.' !important;;';
    }
    if (snsnitan_themeoption('body_bg_type_img') != '') { 
        $body_bg_type_img = snsnitan_getOption('body_bg_type_img', 'image');
        //echo $body_bg_type_img;
        $bodycss .= 'background-image: url('.$body_bg_type_img.') !important;';
    }
    if (snsnitan_themeoption('body_bg-repeat-select') != '') { 
        $body_bg_repeat_select = snsnitan_themeoption('body_bg-repeat-select');
        $bodycss .= 'background-repeat:' .$body_bg_repeat_select.' !important;;';
    }
    if (snsnitan_themeoption('body_bg-size-select') != '') { 
        $body_bg_size_select = snsnitan_themeoption('body_bg-size-select');
        $bodycss .= 'background-size:' .$body_bg_size_select.' !important;;';
    }
    if (snsnitan_themeoption('body_bg-position-select') != '') { 
        $body_bg_position_select = snsnitan_themeoption('body_bg-position-select');
        $bodycss .= 'background-position:' .$body_bg_position_select.' !important;;';
    }
    if (snsnitan_themeoption('body_bg-attachment-select') != '') { 
        $body_bg_attachment_select = snsnitan_themeoption('body_bg-attachment-select');
        $bodycss .= 'background-attachment:' .$body_bg_attachment_select.' !important;;';
    }
    $inline_css .= 'body {'.$bodycss.'}';
    // Selectors use google font
    if(isset($snsnitan_opt['secondary_font_target']) && $snsnitan_opt['secondary_font_target']) {
        if(isset($snsnitan_opt['secondary_font']) && is_array($snsnitan_opt['secondary_font'])) {
            $secondary_font = '';
            foreach($snsnitan_opt['secondary_font'] as $propety => $value)
                if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                    $secondary_font .= $propety . ':' . $value . ';';
            
            if($secondary_font != '') $inline_css .= $snsnitan_opt['secondary_font_target'] . ' {'.$secondary_font.'}';
        }
    }
    // Css for footer
    $footercss = '';
    if( snsnitan_themeoption('footer_img','','url') ){
        $footercss .= 'background-image: url('.snsnitan_getOption('footer_img', 'image').');';
    }else{
        $footercss .= 'background: #4a4a4a;';
    }
    $topfooter_css = '';
    $topfooter_column = '';
    $topfooter_css .= 'background:'.esc_attr( snsnitan_getOption('topfooter_bg_color')).';';
    if ( snsnitan_getOption('footer_border_size') != '' ) {
    $topfooter_css .= 'border-bottom:'.esc_attr( snsnitan_getOption('footer_border_size')).' solid '.esc_attr( snsnitan_getOption('footer_border_color')) .';';
    $topfooter_css .= 'border-top:'.esc_attr( snsnitan_getOption('footer_border_size')).' solid '.esc_attr( snsnitan_getOption('footer_border_color')) .';';
    $topfooter_column = 'border-left:'.esc_attr( snsnitan_getOption('footer_border_size')).' solid '.esc_attr( snsnitan_getOption('footer_border_color')) .';';
    }
    $topfooter_border = '';
    if ( snsnitan_getOption('topfooter_bg_color') == '' && snsnitan_getOption('bottomfooter_bg_color') == '' ) {
        $topfooter_border .= 'border-bottom: 1px solid rgba(255,255,255,.1);';
    }
    $bottomfooter_bg = '';
    if( snsnitan_themeoption('bottomfooter_bg_color') ){
        $bottomfooter_bg .= 'background:'.esc_attr( snsnitan_themeoption('bottomfooter_bg_color')).';';
    }else{
        $bottomfooter_bg .= 'background: none;';
    }
    $inline_css .= '
        #sns_footer_top{'.esc_attr($topfooter_css).'}
        #sns_footer_top .contain{'.esc_attr($topfooter_border).'}
        #sns_footer_top .footer-column{'.esc_attr($topfooter_column).'}
        #sns_footer_bottom{'.esc_attr($bottomfooter_bg).'}
        #sns_footer{'.esc_attr($footercss).'}
    ';
    // Css for Breadcrump
    if( snsnitan_getOption('bg_breadcrump', 'image') ){
        $inline_css .= '#sns_breadcrumbs { background:url('.esc_attr(snsnitan_getOption('bg_breadcrump', 'image')).') no-repeat fixed center top / cover  rgba(0, 0, 0, 0); min-height:350px; }';
    }
    // Custom Css
    $inline_css .= esc_attr(snsnitan_themeoption('advance_customcss'));
    return $inline_css;
}

/* 
 * Add tpl footer
 */
function snsnitan_tplfooter() {
    $output = '';
    ob_start();
    require SNSNITAN_THEME_DIR . '/tpl-footer.php';
    $output = ob_get_clean();
    echo $output;
}
add_action('wp_footer', 'snsnitan_tplfooter');
/* 
 * Custom js to footer
 */
if(!function_exists('snsnitan_wp_foot')){
	function snsnitan_wp_foot(){
		// write out custom code
        $output = '';
        ob_start();
        ?>
		<script type="text/javascript">
        jQuery(document).ready(function(){
            <?php if( snsnitan_themeoption('tag_showmore', '1') == '1' ): ?>
	            if(jQuery('.widget_tag_cloud').length > 0){
					var $tag_display_first 	= <?php echo absint( snsnitan_themeoption('tag_display_first', 7) ) - 1?>;
					var $number_tags 		= jQuery('.widget_tag_cloud .tagcloud a').length;
					var $_this 				= jQuery('.widget_tag_cloud .tagcloud');
					var $view_all_tags		= "<?php echo esc_html__('View all tags', 'snsnitan');?>";
					var $hide_all_tags		= "<?php echo esc_html__('Hide all tags', 'snsnitan');?>";
					
					if( $number_tags > $tag_display_first ){
						jQuery('.widget_tag_cloud .tagcloud a:gt('+$tag_display_first+')').addClass('is_visible').hide();
						jQuery($_this).append('<div class="view-more-tag"><a href="#" title="">'+$view_all_tags+'</a></div>');
	
						jQuery('.widget_tag_cloud .tagcloud .view-more-tag a').click(function(){
							if(jQuery(this).hasClass('active')){
								if( jQuery($_this).find('a').hasClass('is_hidden') ){
									$_this.find('.is_hidden').removeClass('is_hidden').addClass('is_visible').stop().slideUp(300);
								}
								jQuery(this).removeClass('active');
								jQuery(this).html($view_all_tags);
								
							}else{
								if(jQuery($_this).find('a').hasClass('is_visible')){
									$_this.find('.is_visible').removeClass('is_visible').addClass('is_hidden').stop().slideDown(400);
								}
								jQuery(this).addClass('active');
								jQuery(this).html($hide_all_tags);
							}
							
							return false;
						});
					}
	            }
            <?php endif; ?>
            <?php echo esc_js(snsnitan_themeoption('advance_customjs',''));?>
        });
		</script>
        <?php
        $output = ob_get_clean();
        echo $output;
	}
	add_action('wp_footer', 'snsnitan_wp_foot', 100);
}

/** 
 *	Tile for page, post
 **/
function snsnitan_pagetitle(){
	// Disable title in page
	if( is_page() && function_exists('rwmb_meta') && rwmb_meta('snsnitan_showtitle') == '2' ) return;
	// Show title in page, single post
	if( is_single() || is_page() || ( is_home() && get_option( 'show_on_front' ) == 'page' ) ) : ?>
		<h1 class="page-header">
          <?php the_title(); ?>
        </h1>
    <?php 
    // Show title for category page
    elseif ( is_category() ) : ?>
        <h1 class="page-header">
          <?php single_cat_title(); ?>
        </h1>
    <?php
    // Author
    elseif ( is_author() ) : ?>
        <h1 class="page-header">
        <?php
            printf( esc_html__( 'All posts by: %s', 'snsnitan' ), get_the_author() );
        ?>
        </h1>
        <?php if ( get_the_author_meta( 'description' ) ) : ?>
        <header class="archive-header">
            <div class="author-description"><p><?php the_author_meta( 'description' ); ?></p></div>
        </header>
        <?php endif; ?>
    <?php 
    // Tag
    elseif ( is_tag() ) : ?>
        <h1 class="page-header">
            <?php printf( esc_html__( 'Tag Archives: %s', 'snsnitan' ), single_tag_title( '', false ) ); ?>
        </h1>
        <?php
        $term_description = term_description();
        if ( ! empty( $term_description ) ) : ?>
        <header class="archive-header">
            <?php printf( '<div class="taxonomy-description">%s</div>', $term_description ); ?>
        </header>
        <?php endif; ?>
    <?php 
    // Search
    elseif ( is_search() ) : ?>
    <h1 class="page-header"><?php printf( esc_html__( 'Search Results for: %s', 'snsnitan' ), get_search_query() ); ?></h1>
    <?php
    // Archive
    elseif ( is_archive() ) : ?>
        <?php the_archive_title( '<h1 class="page-header">', '</h1>' ); ?>
        <?php
        if( get_the_archive_description() ): ?>
        <header class="archive-header">
            <?php the_archive_description( '<div class="taxonomy-description">', '</div>' ); ?>
        </header>
        <?php    
        endif;
        ?>
    <?php
    // Default
    else : ?>
        <h1 class="page-header">
          <?php the_title(); ?>
        </h1>
    <?php
	endif;
}


// Excerpt Function
if(!function_exists('snsnitan_excerpt')){
    function snsnitan_excerpt($limit, $afterlimit='...') {
        $limit = ($limit) ? $limit : 55 ;
        $excerpt = get_the_excerpt();
        if( $excerpt != '' ){
           $excerpt = explode(' ', strip_tags( $excerpt ), intval($limit));
        }else{
            $excerpt = explode(' ', strip_tags(get_the_content( )), intval($limit));
        }
        if ( count($excerpt) >= $limit ) {
            array_pop($excerpt);
            $excerpt = implode(" ",$excerpt).' '.$afterlimit;
        } else {
            $excerpt = implode(" ",$excerpt);
        }
        $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
        return strip_shortcodes( $excerpt );
    }
}

/*
 * Ajax page navigation
 */
function snsnitan_ajax_load_next_page(){
	// Get current layout
	global $snsnitan_blog_layout, $snsnitan_obj;
	$snsnitan_blog_layout = isset($_POST['snsnitan_blog_layout']) ? esc_html($_POST['snsnitan_blog_layout']) : '';
	if( $snsnitan_blog_layout == '' ) $snsnitan_blog_layout = $snsnitan_obj->snsnitan_getOption('blog_type');
	
	// Get current page
	$page = $_POST['page'];
	
	// Number of published sticky posts
	$sticky_posts = snsnitan_get_sticky_posts_count();
	
	// Current query vars
	$vars = $_POST['vars'];
	
	// Convert string value into corresponding data types
	foreach ($vars as $key => $value){
		if( is_numeric($value) ) $vars[$key] = intval($value);
		if( $value == 'false' ) $vars[$key] = false;
		if( $value == 'true' ) $vars[$key] = true;
	}
	
	// Item template file 
	$template = $_POST['template'];
	
	// Return next page
	$page = intval($page) + 1;
	
	$posts_per_page = get_option('posts_per_page');
    if( $page == 2 && $vars['posts_per_page'] ){
        $offset = $vars['posts_per_page'];
    }else{
        $offset = $vars['posts_per_page'] + ($page - 2) * $posts_per_page;
    }
	
	/*
	 * This is confusing. Just leave it here to later reference
	 *
	
	 if(!$vars['ignore_sticky_posts']){
	 $offset += $sticky_posts;
	 }
	 *
	 */
	
	// Get more posts per page than necessary to detect if there are more posts
	$args = array('post_status'=>'publish', 'posts_per_page'=>$posts_per_page + 1, 'offset'=>$offset);
	$args = array_merge($vars, $args);
	
	// Remove unnecessary variables
	unset($args['paged']);
	unset($args['p']);
	unset($args['page']);
	unset($args['pagename']); // This is necessary in case Posts Page is set to static page
	
	$query = new WP_Query($args);
	
	$idx = 0;
	if( $query->have_posts() ){
		while ( $query->have_posts() ){
			$query->the_post();
			$idx = $idx + 1;
			if( $idx < $posts_per_page + 1 )
				get_template_part($template, get_post_format());
		}
		
		if( $query->post_count <= $posts_per_page ){
			// There are no more posts
			// Print a flag to detect
			echo '<div id="sns-load-more-no-posts" class="no-posts"><!-- --></div>';
		}
	}else{
		// No posts found
	}
	
	/* Restore original Post Data*/
	wp_reset_postdata();
	
	die('');
}
// When the request action is "load_more", the snsnitan_ajax_load_next_page() will be called
add_action('wp_ajax_load_more', 'snsnitan_ajax_load_next_page');
add_action('wp_ajax_nopriv_load_more', 'snsnitan_ajax_load_next_page');

// Word Limiter
function snsnitan_limitwords($string, $word_limit) {
    $words = explode(' ', $string);
    return implode(' ', array_slice($words, 0, $word_limit));
}
//
if(!function_exists('snsnitan_sharebox')){
    function snsnitan_sharebox( $layout='',$args=array() ){
        global $post, $snsnitan_obj;
        $default = array(
            'position' => 'top',
            'animation' => 'true'
            );
        $args = wp_parse_args( (array) $args, $default );
        ?>
        <div class="sns-share-box">
            <ul class="socials">
                <?php if($snsnitan_obj->snsnitan_getOption('show_facebook_sharebox')==1): ?>
                <li class="facebook">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr( $args['position'] ); ?>" data-animation="<?php echo esc_attr($args['animation'] ); ?>"  data-original-title="<?php echo esc_html__('Facebook', 'snsnitan'); ?>" href="http://www.facebook.com/sharer.php?s=100&p&#91;url&#93;=<?php the_permalink(); ?>&p&#91;title&#93;=<?php the_title(); ?>" target="_blank">
                        <i class="fa fa-facebook"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_twitter_sharebox')==1): ?>
                <li class="twitter">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('Twitter', 'snsnitan'); ?>" href="http://twitter.com/home?status=<?php the_title(); ?> <?php the_permalink(); ?>" target="_blank">
                        <i class="fa fa-twitter"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_linkedin_sharebox')==1): ?>
                <li class="linkedin">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('LinkedIn', 'snsnitan'); ?>" href="http://linkedin.com/shareArticle?mini=true&amp;url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" target="_blank">
                        <i class="fa fa-linkedin"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_tumblr_sharebox')==1): ?>
                <li class="tumblr">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('Tumblr', 'snsnitan'); ?>" href="http://www.tumblr.com/share/link?url=<?php echo urlencode(get_permalink()); ?>&amp;name=<?php echo urlencode($post->post_title); ?>&amp;description=<?php echo urlencode(get_the_excerpt()); ?>" target="_blank">
                        <i class="fa fa-tumblr"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_gplus_sharebox')==1): ?>
                <li class="google">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('Google +1', 'snsnitan'); ?>" href="https://plus.google.com/share?url=<?php the_permalink(); ?>" onclick="javascript:window.open(this.href,
            '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" target="_blank">
                        <i class="fa fa-google-plus"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_pinterest_sharebox')==1): ?>
                <li class="pinterest">
                    <?php $full_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full'); ?>
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('Pinterest', 'snsnitan'); ?>" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&amp;description=<?php echo urlencode($post->post_title); ?>&amp;media=<?php echo urlencode($full_image[0]); ?>" target="_blank">
                        <i class="fa fa-pinterest"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsnitan_obj->snsnitan_getOption('show_email_sharebox')==1): ?>
                <li class="email">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="<?php echo esc_html__('Email', 'snsnitan'); ?>" href="mailto:?subject=<?php the_title(); ?>&amp;body=<?php the_permalink(); ?>">
                        <i class="fa fa-envelope"></i>
                    </a>
                </li>
                <?php endif; ?>
            </ul>
        </div>
        <?php
    }
}
//
if(!function_exists('snsnitan_relatedpost')){
    function snsnitan_relatedpost(){
        global $post;
        if($post){
        	$post_id = $post->ID;
        }else{
        	// Return if cannot find any post
        }
        
        $relate_count = snsnitan_themeoption('related_num');
        $get_related_post_by = snsnitan_themeoption('related_posts_by');

        $args = array(
            'post_status' => 'publish',
            'posts_per_page' => $relate_count,
            'orderby' => 'date',
            'ignore_sticky_posts' => 1,
            'post__not_in' => array ($post_id)
        );
        
        if($get_related_post_by == 'cat'){
        	$categories = wp_get_post_categories($post_id);
        	$args['category__in'] = $categories;
        }else{
        	$posttags = wp_get_post_tags($post_id);
        	
        	$array_tags = array();
        	if($posttags){
        		foreach ($posttags as $tag){
        			$tags = $tag->term_id;
        			array_push($array_tags, $tags);
        		}
        	}
        	$args['tag__in'] = $array_tags;
        }
        
        $relates = new WP_Query( $args );
        
        $template_name = '/framework/tpl/posts/related_post.php';
        if(is_file(SNSNITAN_THEME_DIR.$template_name)) {
            include(SNSNITAN_THEME_DIR.$template_name);
        }
        
        wp_reset_postdata();
    }
}

/*
 * Function to display number of posts.
 */
function snsnitan_get_post_views($post_id){
	$count_key = 'post_views_count';
	$count = get_post_meta($post_id, $count_key, true);
	if($count == ''){
		delete_post_meta($post_id, $count_key);
		add_post_meta($post_id, $count_key, '0');
		return esc_html__('0 view', 'snsnitan');
	}
	return $count. esc_html__(' View', 'snsnitan');
}

/*
 * Function to count views.
 */
function snsnitan_set_post_views($post_id){
	$count_key = 'post_views_count';
	$count = get_post_meta($post_id, $count_key, true);
	if($count == ''){
		$count = 0;
		delete_post_meta($post_id, $count_key);
		add_post_meta($post_id, $count_key, '0');
	}else{
		$count++;
		update_post_meta($post_id, $count_key, $count);
	}
}


function snsnitan_comment($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment; ?>
    <?php $add_below = ''; ?>
    <li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
        <div class="comment-body">
        	<div class="comment-user-meta">
        		<?php echo get_avatar($comment, 50); ?>
        		<div>
        			<h4 class="comment-user"><?php echo get_comment_author_link(); ?></h4>
	            	<div class="comment-meta"><?php printf(esc_html__('%1$s at %2$s,', 'snsnitan'), get_comment_date(),  get_comment_time()) ?></div>
        		</div>
        	</div>
            <div class="comment-content">
            	<?php if ($comment->comment_approved == '0') : ?>
	            <p>
	                <em><?php echo esc_html__('Your comment is awaiting moderation.', 'snsnitan') ?></em><br />
	            </p>
	            <?php endif; ?>
	             <?php comment_text() ?>
	            <div class="reply">
	              <?php edit_comment_link(esc_html__('Edit', 'snsnitan'),'  ','') ?>
	              <?php comment_reply_link(array_merge( $args, array('reply_text' => esc_html__('Reply', 'snsnitan'), 'add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth'])))?>
	            </div>
            </div>
        </div>
  <?php 
}
/** 
 *	Breadcrumbs
 **/
function snsnitan_breadcrumbs(){
    $template_name = '/tpl-breadcrumb.php';
	if(is_file(SNSNITAN_THEME_DIR.$template_name)) {
        include(SNSNITAN_THEME_DIR.$template_name);
    }
}

/*
 * Woocommerce advanced search functionlity
 */
add_action('pre_get_posts', 'snsnitan_advanced_search_query', 1000);
function snsnitan_advanced_search_query($query){
	if($query->is_search()) {
		// Category terms search
		if( isset($_GET['snsnitan_woo_category']) && !empty($_GET['snsnitan_woo_category']) ){
			$query->set('tax_query', array(array(
				'taxonomy' 	=> 'product_cat',
				'field'		=> 'slug',
				'term'		=> array($_GET['snsnitan_woo_category']) )
			));
		}
	}
	return $query;
}

/* Sample data */
add_action( 'admin_enqueue_scripts', 'snsnitan_importlib' );
function snsnitan_importlib(){
    wp_enqueue_script('sampledata', SNSNITAN_THEME_URI . '/framework/sample-data/assets/script.js', array('jquery'), '', true);
    wp_enqueue_style('sampledata-css', SNSNITAN_THEME_URI . '/framework/sample-data/assets/style.css');
}
add_action( 'wp_ajax_sampledata', 'snsnitan_importsampledata' );
function snsnitan_importsampledata(){
    include_once(SNSNITAN_THEME_DIR . '/framework/sample-data/sns-importdata.php');
    snsnitan_importdata();
}

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328234&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>